""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.udb.schemas import models

""" UDB API Schema
"""


"""
API: BackupUDBInstance

备份UDB实例
"""


class BackupUDBInstanceRequestSchema(schema.RequestSchema):
    """BackupUDBInstance - 备份UDB实例"""

    fields = {
        "BackupMethod": fields.Str(required=False, dump_to="BackupMethod"),
        "BackupName": fields.Str(required=True, dump_to="BackupName"),
        "Blacklist": fields.Str(required=False, dump_to="Blacklist"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ForceBackup": fields.Bool(required=False, dump_to="ForceBackup"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UseBlacklist": fields.Bool(required=False, dump_to="UseBlacklist"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class BackupUDBInstanceResponseSchema(schema.ResponseSchema):
    """BackupUDBInstance - 备份UDB实例"""

    fields = {}


"""
API: BackupUDBInstanceBinlog

备份UDB指定时间段的binlog列表
"""


class BackupUDBInstanceBinlogRequestSchema(schema.RequestSchema):
    """BackupUDBInstanceBinlog - 备份UDB指定时间段的binlog列表"""

    fields = {
        "BackupFile": fields.Str(required=True, dump_to="BackupFile"),
        "BackupName": fields.Str(required=False, dump_to="BackupName"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class BackupUDBInstanceBinlogResponseSchema(schema.ResponseSchema):
    """BackupUDBInstanceBinlog - 备份UDB指定时间段的binlog列表"""

    fields = {}


"""
API: BackupUDBInstanceErrorLog

备份UDB指定时间段的errorlog
"""


class BackupUDBInstanceErrorLogRequestSchema(schema.RequestSchema):
    """BackupUDBInstanceErrorLog - 备份UDB指定时间段的errorlog"""

    fields = {
        "BackupName": fields.Str(required=True, dump_to="BackupName"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class BackupUDBInstanceErrorLogResponseSchema(schema.ResponseSchema):
    """BackupUDBInstanceErrorLog - 备份UDB指定时间段的errorlog"""

    fields = {}


"""
API: BackupUDBInstanceSlowLog

备份UDB指定时间段的slowlog分析结果
"""


class BackupUDBInstanceSlowLogRequestSchema(schema.RequestSchema):
    """BackupUDBInstanceSlowLog - 备份UDB指定时间段的slowlog分析结果"""

    fields = {
        "BackupName": fields.Str(required=True, dump_to="BackupName"),
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class BackupUDBInstanceSlowLogResponseSchema(schema.ResponseSchema):
    """BackupUDBInstanceSlowLog - 备份UDB指定时间段的slowlog分析结果"""

    fields = {}


"""
API: ChangeUDBParamGroup

修改配置文件
"""


class ChangeUDBParamGroupRequestSchema(schema.RequestSchema):
    """ChangeUDBParamGroup - 修改配置文件"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "GroupId": fields.Str(required=True, dump_to="GroupId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ChangeUDBParamGroupResponseSchema(schema.ResponseSchema):
    """ChangeUDBParamGroup - 修改配置文件"""

    fields = {}


"""
API: CheckRecoverUDBInstance

核查db是否可以使用回档功能
"""


class CheckRecoverUDBInstanceRequestSchema(schema.RequestSchema):
    """CheckRecoverUDBInstance - 核查db是否可以使用回档功能"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SrcDBId": fields.Str(required=True, dump_to="SrcDBId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class CheckRecoverUDBInstanceResponseSchema(schema.ResponseSchema):
    """CheckRecoverUDBInstance - 核查db是否可以使用回档功能"""

    fields = {
        "LastestTime": fields.Int(required=False, load_from="LastestTime"),
    }


"""
API: CheckUDBInstanceToHAAllowance

核查db是否可以升级为高可用
"""


class CheckUDBInstanceToHAAllowanceRequestSchema(schema.RequestSchema):
    """CheckUDBInstanceToHAAllowance - 核查db是否可以升级为高可用"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class CheckUDBInstanceToHAAllowanceResponseSchema(schema.ResponseSchema):
    """CheckUDBInstanceToHAAllowance - 核查db是否可以升级为高可用"""

    fields = {
        "Allowance": fields.Str(required=False, load_from="Allowance"),
    }


"""
API: ClearUDBLog

清除UDB实例的log
"""


class ClearUDBLogRequestSchema(schema.RequestSchema):
    """ClearUDBLog - 清除UDB实例的log"""

    fields = {
        "BeforeTime": fields.Int(required=False, dump_to="BeforeTime"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "LogType": fields.Int(required=True, dump_to="LogType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ClearUDBLogResponseSchema(schema.ResponseSchema):
    """ClearUDBLog - 清除UDB实例的log"""

    fields = {}


"""
API: CreateMongoDBReplicaSet

一键创建DB副本集
"""


class CreateMongoDBReplicaSetRequestSchema(schema.RequestSchema):
    """CreateMongoDBReplicaSet - 一键创建DB副本集"""

    fields = {
        "AdminPassword": fields.Str(required=True, dump_to="AdminPassword"),
        "AdminUser": fields.Str(required=False, dump_to="AdminUser"),
        "BackupCount": fields.Int(required=False, dump_to="BackupCount"),
        "BackupDuration": fields.Int(required=False, dump_to="BackupDuration"),
        "BackupTime": fields.Int(required=False, dump_to="BackupTime"),
        "CPU": fields.Int(required=False, dump_to="CPU"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "ClusterId": fields.Str(required=False, dump_to="ClusterId"),
        "CouponId": fields.List(fields.Str()),
        "DBTypeId": fields.Str(required=True, dump_to="DBTypeId"),
        "DiskSpace": fields.Int(required=True, dump_to="DiskSpace"),
        "InstanceType": fields.Str(required=False, dump_to="InstanceType"),
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ParamGroupId": fields.Int(required=True, dump_to="ParamGroupId"),
        "Port": fields.Int(required=True, dump_to="Port"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSDType": fields.Str(required=False, dump_to="SSDType"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "UseSSD": fields.Bool(required=False, dump_to="UseSSD"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateMongoDBReplicaSetResponseSchema(schema.ResponseSchema):
    """CreateMongoDBReplicaSet - 一键创建DB副本集"""

    fields = {
        "Action": fields.Str(required=True, load_from="Action"),
        "DBIds": fields.List(fields.Str(), required=False, load_from="DBIds"),
        "RetCode": fields.Int(required=True, load_from="RetCode"),
    }


"""
API: CreateUDBInstance

创建UDB实例（包括创建mysql master节点、mongodb primary/configsvr节点和从备份恢复实例）
"""


class CreateUDBInstanceRequestSchema(schema.RequestSchema):
    """CreateUDBInstance - 创建UDB实例（包括创建mysql master节点、mongodb primary/configsvr节点和从备份恢复实例）"""

    fields = {
        "AdminPassword": fields.Str(required=True, dump_to="AdminPassword"),
        "AdminUser": fields.Str(required=False, dump_to="AdminUser"),
        "BackupCount": fields.Int(required=False, dump_to="BackupCount"),
        "BackupDuration": fields.Int(required=False, dump_to="BackupDuration"),
        "BackupId": fields.Int(required=False, dump_to="BackupId"),
        "BackupTime": fields.Int(required=False, dump_to="BackupTime"),
        "BackupZone": fields.Str(required=False, dump_to="BackupZone"),
        "CPU": fields.Int(required=False, dump_to="CPU"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "ClusterRole": fields.Str(required=False, dump_to="ClusterRole"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "DBTypeId": fields.Str(required=True, dump_to="DBTypeId"),
        "DisableSemisync": fields.Bool(
            required=False, dump_to="DisableSemisync"
        ),
        "DiskSpace": fields.Int(required=True, dump_to="DiskSpace"),
        "EnableIpV6": fields.Bool(required=False, dump_to="EnableIpV6"),
        "HAArch": fields.Str(required=False, dump_to="HAArch"),
        "InstanceMode": fields.Str(required=False, dump_to="InstanceMode"),
        "InstanceType": fields.Str(
            required=False, dump_to="InstanceType"
        ),  # Deprecated, will be removed at 1.0
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ParamGroupId": fields.Int(required=True, dump_to="ParamGroupId"),
        "Port": fields.Int(required=True, dump_to="Port"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSDType": fields.Str(required=False, dump_to="SSDType"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "UDBCId": fields.Str(required=False, dump_to="UDBCId"),
        "UseSSD": fields.Bool(required=False, dump_to="UseSSD"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUDBInstanceResponseSchema(schema.ResponseSchema):
    """CreateUDBInstance - 创建UDB实例（包括创建mysql master节点、mongodb primary/configsvr节点和从备份恢复实例）"""

    fields = {
        "DBId": fields.Str(required=False, load_from="DBId"),
    }


"""
API: CreateUDBInstanceByRecovery

创建db，将新创建的db恢复到指定db某个指定时间点
"""


class CreateUDBInstanceByRecoveryRequestSchema(schema.RequestSchema):
    """CreateUDBInstanceByRecovery - 创建db，将新创建的db恢复到指定db某个指定时间点"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "EnableIpV6": fields.Bool(required=False, dump_to="EnableIpV6"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "RecoveryTime": fields.Int(required=True, dump_to="RecoveryTime"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SrcDBId": fields.Str(required=True, dump_to="SrcDBId"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "UDBCId": fields.Str(required=False, dump_to="UDBCId"),
        "UseSSD": fields.Bool(required=False, dump_to="UseSSD"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class CreateUDBInstanceByRecoveryResponseSchema(schema.ResponseSchema):
    """CreateUDBInstanceByRecovery - 创建db，将新创建的db恢复到指定db某个指定时间点"""

    fields = {
        "DBId": fields.Str(required=False, load_from="DBId"),
    }


"""
API: CreateUDBParamGroup

从已有配置文件创建新配置文件
"""


class CreateUDBParamGroupRequestSchema(schema.RequestSchema):
    """CreateUDBParamGroup - 从已有配置文件创建新配置文件"""

    fields = {
        "DBTypeId": fields.Str(required=True, dump_to="DBTypeId"),
        "Description": fields.Str(required=True, dump_to="Description"),
        "GroupName": fields.Str(required=True, dump_to="GroupName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RegionFlag": fields.Bool(required=False, dump_to="RegionFlag"),
        "SrcGroupId": fields.Int(required=True, dump_to="SrcGroupId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUDBParamGroupResponseSchema(schema.ResponseSchema):
    """CreateUDBParamGroup - 从已有配置文件创建新配置文件"""

    fields = {
        "GroupId": fields.Int(required=False, load_from="GroupId"),
    }


"""
API: CreateUDBReplicationInstance

创建MongoDB的副本节点（包括仲裁）
"""


class CreateUDBReplicationInstanceRequestSchema(schema.RequestSchema):
    """CreateUDBReplicationInstance - 创建MongoDB的副本节点（包括仲裁）"""

    fields = {
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "IsArbiter": fields.Bool(required=False, dump_to="IsArbiter"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "Port": fields.Int(required=False, dump_to="Port"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SrcId": fields.Str(required=True, dump_to="SrcId"),
        "UseSSD": fields.Bool(required=False, dump_to="UseSSD"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class CreateUDBReplicationInstanceResponseSchema(schema.ResponseSchema):
    """CreateUDBReplicationInstance - 创建MongoDB的副本节点（包括仲裁）"""

    fields = {
        "DBId": fields.Str(required=False, load_from="DBId"),
    }


"""
API: CreateUDBRouteInstance

创建mongos实例
"""


class CreateUDBRouteInstanceRequestSchema(schema.RequestSchema):
    """CreateUDBRouteInstance - 创建mongos实例"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "ConfigsvrId": fields.List(fields.Str()),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "DBTypeId": fields.Str(required=True, dump_to="DBTypeId"),
        "DiskSpace": fields.Int(required=True, dump_to="DiskSpace"),
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ParamGroupId": fields.Int(required=True, dump_to="ParamGroupId"),
        "Port": fields.Int(required=True, dump_to="Port"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UseSSD": fields.Bool(required=False, dump_to="UseSSD"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class CreateUDBRouteInstanceResponseSchema(schema.ResponseSchema):
    """CreateUDBRouteInstance - 创建mongos实例"""

    fields = {
        "DBId": fields.Str(required=False, load_from="DBId"),
    }


"""
API: CreateUDBSlave

创建UDB实例的slave
"""


class CreateUDBSlaveRequestSchema(schema.RequestSchema):
    """CreateUDBSlave - 创建UDB实例的slave"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "DiskSpace": fields.Int(required=False, dump_to="DiskSpace"),
        "InstanceMode": fields.Str(required=False, dump_to="InstanceMode"),
        "InstanceType": fields.Str(required=False, dump_to="InstanceType"),
        "IsLock": fields.Bool(required=False, dump_to="IsLock"),
        "MemoryLimit": fields.Int(required=False, dump_to="MemoryLimit"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ParamGroupId": fields.Int(required=False, dump_to="ParamGroupId"),
        "Port": fields.Int(required=False, dump_to="Port"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSDType": fields.Str(required=False, dump_to="SSDType"),
        "SrcId": fields.Str(required=True, dump_to="SrcId"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "UseSSD": fields.Bool(required=False, dump_to="UseSSD"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class CreateUDBSlaveResponseSchema(schema.ResponseSchema):
    """CreateUDBSlave - 创建UDB实例的slave"""

    fields = {
        "DBId": fields.Str(required=False, load_from="DBId"),
    }


"""
API: DeleteUDBBackup


"""


class DeleteUDBBackupRequestSchema(schema.RequestSchema):
    """DeleteUDBBackup -"""

    fields = {
        "BackupId": fields.Int(required=True, dump_to="BackupId"),
        "BackupZone": fields.Str(required=False, dump_to="BackupZone"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteUDBBackupResponseSchema(schema.ResponseSchema):
    """DeleteUDBBackup -"""

    fields = {}


"""
API: DeleteUDBInstance

删除UDB实例
"""


class DeleteUDBInstanceRequestSchema(schema.RequestSchema):
    """DeleteUDBInstance - 删除UDB实例"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDBCId": fields.Str(required=False, dump_to="UDBCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DeleteUDBInstanceResponseSchema(schema.ResponseSchema):
    """DeleteUDBInstance - 删除UDB实例"""

    fields = {}


"""
API: DeleteUDBLogPackage

删除UDB日志包
"""


class DeleteUDBLogPackageRequestSchema(schema.RequestSchema):
    """DeleteUDBLogPackage - 删除UDB日志包"""

    fields = {
        "BackupId": fields.Int(required=True, dump_to="BackupId"),
        "BackupZone": fields.Str(required=False, dump_to="BackupZone"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteUDBLogPackageResponseSchema(schema.ResponseSchema):
    """DeleteUDBLogPackage - 删除UDB日志包"""

    fields = {}


"""
API: DeleteUDBParamGroup

删除配置参数组
"""


class DeleteUDBParamGroupRequestSchema(schema.RequestSchema):
    """DeleteUDBParamGroup - 删除配置参数组"""

    fields = {
        "GroupId": fields.Int(required=True, dump_to="GroupId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RegionFlag": fields.Bool(required=False, dump_to="RegionFlag"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteUDBParamGroupResponseSchema(schema.ResponseSchema):
    """DeleteUDBParamGroup - 删除配置参数组"""

    fields = {}


"""
API: DescribeUDBBackup

列表UDB实例备份信息
"""


class DescribeUDBBackupRequestSchema(schema.RequestSchema):
    """DescribeUDBBackup - 列表UDB实例备份信息"""

    fields = {
        "BackupId": fields.Int(
            required=False, dump_to="BackupId"
        ),  # Deprecated, will be removed at 1.0
        "BackupType": fields.Int(required=False, dump_to="BackupType"),
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "ClassType": fields.Str(
            required=False, dump_to="ClassType"
        ),  # Deprecated, will be removed at 1.0
        "DBId": fields.Str(required=False, dump_to="DBId"),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "Limit": fields.Int(required=True, dump_to="Limit"),
        "Offset": fields.Int(required=True, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBBackupResponseSchema(schema.ResponseSchema):
    """DescribeUDBBackup - 列表UDB实例备份信息"""

    fields = {
        "DataSet": fields.List(
            models.UDBBackupSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUDBBackupBlacklist

获取UDB实例的备份黑名单
"""


class DescribeUDBBackupBlacklistRequestSchema(schema.RequestSchema):
    """DescribeUDBBackupBlacklist - 获取UDB实例的备份黑名单"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBBackupBlacklistResponseSchema(schema.ResponseSchema):
    """DescribeUDBBackupBlacklist - 获取UDB实例的备份黑名单"""

    fields = {
        "Blacklist": fields.Str(required=False, load_from="Blacklist"),
    }


"""
API: DescribeUDBBinlogBackupURL

获取UDB的Binlog备份地址
"""


class DescribeUDBBinlogBackupURLRequestSchema(schema.RequestSchema):
    """DescribeUDBBinlogBackupURL - 获取UDB的Binlog备份地址"""

    fields = {
        "BackupId": fields.Int(required=True, dump_to="BackupId"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBBinlogBackupURLResponseSchema(schema.ResponseSchema):
    """DescribeUDBBinlogBackupURL - 获取UDB的Binlog备份地址"""

    fields = {
        "BackupPath": fields.Str(required=False, load_from="BackupPath"),
        "InnerBackupPath": fields.Str(
            required=False, load_from="InnerBackupPath"
        ),
    }


"""
API: DescribeUDBInstance

获取UDB实例信息，支持两类操作：（1）指定DBId用于获取该db的信息；（2）指定ClassType、Offset、Limit用于列表操作，查询某一个类型db。
"""


class DescribeUDBInstanceRequestSchema(schema.RequestSchema):
    """DescribeUDBInstance - 获取UDB实例信息，支持两类操作：（1）指定DBId用于获取该db的信息；（2）指定ClassType、Offset、Limit用于列表操作，查询某一个类型db。"""

    fields = {
        "ClassType": fields.Str(required=False, dump_to="ClassType"),
        "DBId": fields.Str(required=False, dump_to="DBId"),
        "IncludeSlaves": fields.Bool(required=False, dump_to="IncludeSlaves"),
        "IsInUDBC": fields.Bool(required=False, dump_to="IsInUDBC"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDBCId": fields.Str(required=False, dump_to="UDBCId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBInstanceResponseSchema(schema.ResponseSchema):
    """DescribeUDBInstance - 获取UDB实例信息，支持两类操作：（1）指定DBId用于获取该db的信息；（2）指定ClassType、Offset、Limit用于列表操作，查询某一个类型db。"""

    fields = {
        "DataSet": fields.List(
            models.UDBInstanceSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUDBInstanceBackupState

获取UDB实例备份状态
"""


class DescribeUDBInstanceBackupStateRequestSchema(schema.RequestSchema):
    """DescribeUDBInstanceBackupState - 获取UDB实例备份状态"""

    fields = {
        "BackupId": fields.Int(required=True, dump_to="BackupId"),
        "BackupZone": fields.Str(required=False, dump_to="BackupZone"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDBInstanceBackupStateResponseSchema(schema.ResponseSchema):
    """DescribeUDBInstanceBackupState - 获取UDB实例备份状态"""

    fields = {
        "BackupEndTime": fields.Int(required=False, load_from="BackupEndTime"),
        "BackupSize": fields.Int(required=False, load_from="BackupSize"),
        "State": fields.Str(required=False, load_from="State"),
    }


"""
API: DescribeUDBInstanceBackupURL

获取UDB备份下载地址
"""


class DescribeUDBInstanceBackupURLRequestSchema(schema.RequestSchema):
    """DescribeUDBInstanceBackupURL - 获取UDB备份下载地址"""

    fields = {
        "BackupId": fields.Int(required=True, dump_to="BackupId"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBInstanceBackupURLResponseSchema(schema.ResponseSchema):
    """DescribeUDBInstanceBackupURL - 获取UDB备份下载地址"""

    fields = {
        "BackupPath": fields.Str(required=False, load_from="BackupPath"),
        "InnerBackupPath": fields.Str(
            required=False, load_from="InnerBackupPath"
        ),
    }


"""
API: DescribeUDBInstanceBinlog

获取UDB指定时间段的binlog列表
"""


class DescribeUDBInstanceBinlogRequestSchema(schema.RequestSchema):
    """DescribeUDBInstanceBinlog - 获取UDB指定时间段的binlog列表"""

    fields = {
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBInstanceBinlogResponseSchema(schema.ResponseSchema):
    """DescribeUDBInstanceBinlog - 获取UDB指定时间段的binlog列表"""

    fields = {
        "DataSet": fields.List(
            models.UDBInstanceBinlogSetSchema(),
            required=False,
            load_from="DataSet",
        ),
    }


"""
API: DescribeUDBInstanceBinlogBackupState

获取udb实例备份状态
"""


class DescribeUDBInstanceBinlogBackupStateRequestSchema(schema.RequestSchema):
    """DescribeUDBInstanceBinlogBackupState - 获取udb实例备份状态"""

    fields = {
        "BackupId": fields.Int(required=True, dump_to="BackupId"),
        "BackupZone": fields.Str(required=False, dump_to="BackupZone"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDBInstanceBinlogBackupStateResponseSchema(schema.ResponseSchema):
    """DescribeUDBInstanceBinlogBackupState - 获取udb实例备份状态"""

    fields = {
        "BackupSize": fields.Int(
            required=False, load_from="BackupSize"
        ),  # Deprecated, will be removed at 1.0
        "State": fields.Str(required=False, load_from="State"),
    }


"""
API: DescribeUDBInstanceLog

查询某一段时间内UDB的错误日志或慢查询日志
"""


class DescribeUDBInstanceLogRequestSchema(schema.RequestSchema):
    """DescribeUDBInstanceLog - 查询某一段时间内UDB的错误日志或慢查询日志"""

    fields = {
        "BeginTime": fields.Int(required=True, dump_to="BeginTime"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "LogType": fields.Str(required=True, dump_to="LogType"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBInstanceLogResponseSchema(schema.ResponseSchema):
    """DescribeUDBInstanceLog - 查询某一段时间内UDB的错误日志或慢查询日志"""

    fields = {
        "Log": fields.Str(required=False, load_from="Log"),
        "NextTime": fields.Str(required=False, load_from="NextTime"),
    }


"""
API: DescribeUDBInstancePrice

获取UDB实例价格信息
"""


class DescribeUDBInstancePriceRequestSchema(schema.RequestSchema):
    """DescribeUDBInstancePrice - 获取UDB实例价格信息"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "Count": fields.Int(required=False, dump_to="Count"),
        "DBTypeId": fields.Str(required=True, dump_to="DBTypeId"),
        "DiskSpace": fields.Int(required=True, dump_to="DiskSpace"),
        "InstanceMode": fields.Str(required=False, dump_to="InstanceMode"),
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSDType": fields.Str(required=False, dump_to="SSDType"),
        "UseSSD": fields.Str(required=False, dump_to="UseSSD"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDBInstancePriceResponseSchema(schema.ResponseSchema):
    """DescribeUDBInstancePrice - 获取UDB实例价格信息"""

    fields = {
        "DataSet": fields.List(
            models.UDBInstancePriceSetSchema(),
            required=False,
            load_from="DataSet",
        ),
    }


"""
API: DescribeUDBInstanceState

获取UDB实例状态
"""


class DescribeUDBInstanceStateRequestSchema(schema.RequestSchema):
    """DescribeUDBInstanceState - 获取UDB实例状态"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBInstanceStateResponseSchema(schema.ResponseSchema):
    """DescribeUDBInstanceState - 获取UDB实例状态"""

    fields = {
        "State": fields.Str(required=False, load_from="State"),
    }


"""
API: DescribeUDBInstanceUpgradePrice

获取UDB实例升降级价格信息
"""


class DescribeUDBInstanceUpgradePriceRequestSchema(schema.RequestSchema):
    """DescribeUDBInstanceUpgradePrice - 获取UDB实例升降级价格信息"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "DiskSpace": fields.Int(required=True, dump_to="DiskSpace"),
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSDType": fields.Str(required=False, dump_to="SSDType"),
        "UseSSD": fields.Bool(required=False, dump_to="UseSSD"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBInstanceUpgradePriceResponseSchema(schema.ResponseSchema):
    """DescribeUDBInstanceUpgradePrice - 获取UDB实例升降级价格信息"""

    fields = {
        "Price": fields.Int(required=False, load_from="Price"),
    }


"""
API: DescribeUDBLogBackupURL

获取UDB的slowlog备份地址
"""


class DescribeUDBLogBackupURLRequestSchema(schema.RequestSchema):
    """DescribeUDBLogBackupURL - 获取UDB的slowlog备份地址"""

    fields = {
        "BackupId": fields.Int(required=True, dump_to="BackupId"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBLogBackupURLResponseSchema(schema.ResponseSchema):
    """DescribeUDBLogBackupURL - 获取UDB的slowlog备份地址"""

    fields = {
        "BackupPath": fields.Str(required=False, load_from="BackupPath"),
        "UsernetPath": fields.Str(required=False, load_from="UsernetPath"),
    }


"""
API: DescribeUDBLogPackage

列表UDB实例binlog或slowlog或errorlog备份信息
"""


class DescribeUDBLogPackageRequestSchema(schema.RequestSchema):
    """DescribeUDBLogPackage - 列表UDB实例binlog或slowlog或errorlog备份信息"""

    fields = {
        "BeginTime": fields.Int(required=False, dump_to="BeginTime"),
        "DBId": fields.Str(required=False, dump_to="DBId"),
        "EndTime": fields.Int(required=False, dump_to="EndTime"),
        "Limit": fields.Int(required=True, dump_to="Limit"),
        "Offset": fields.Int(required=True, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Type": fields.Int(required=False, dump_to="Type"),
        "Types": fields.List(fields.Int()),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBLogPackageResponseSchema(schema.ResponseSchema):
    """DescribeUDBLogPackage - 列表UDB实例binlog或slowlog或errorlog备份信息"""

    fields = {
        "DataSet": fields.List(
            models.LogPackageDataSetSchema(),
            required=False,
            load_from="DataSet",
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUDBParamGroup

获取参数组详细参数信息
"""


class DescribeUDBParamGroupRequestSchema(schema.RequestSchema):
    """DescribeUDBParamGroup - 获取参数组详细参数信息"""

    fields = {
        "ClassType": fields.Str(required=False, dump_to="ClassType"),
        "GroupId": fields.Int(required=False, dump_to="GroupId"),
        "IsInUDBC": fields.Bool(required=False, dump_to="IsInUDBC"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RegionFlag": fields.Bool(required=False, dump_to="RegionFlag"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class DescribeUDBParamGroupResponseSchema(schema.ResponseSchema):
    """DescribeUDBParamGroup - 获取参数组详细参数信息"""

    fields = {
        "DataSet": fields.List(
            models.UDBParamGroupSetSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=False, load_from="TotalCount"),
    }


"""
API: DescribeUDBSplittingInfo

描述读写分离功能的详细信息
"""


class DescribeUDBSplittingInfoRequestSchema(schema.RequestSchema):
    """DescribeUDBSplittingInfo - 描述读写分离功能的详细信息"""

    fields = {
        "MasterDBId": fields.Str(required=True, dump_to="MasterDBId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDBSplittingInfoResponseSchema(schema.ResponseSchema):
    """DescribeUDBSplittingInfo - 描述读写分离功能的详细信息"""

    fields = {
        "DBTypeId": fields.Str(required=False, load_from="DBTypeId"),
        "DataSet": fields.List(
            models.UDBRWSplittingSetSchema(),
            required=False,
            load_from="DataSet",
        ),
        "DelayThreshold": fields.Int(
            required=False, load_from="DelayThreshold"
        ),
        "MasterDBId": fields.Str(required=False, load_from="MasterDBId"),
        "Port": fields.Int(required=False, load_from="Port"),
        "RWIP": fields.Str(required=False, load_from="RWIP"),
        "RWState": fields.Str(required=False, load_from="RWState"),
        "ReadModel": fields.Str(required=False, load_from="ReadModel"),
        "Zone": fields.Str(required=False, load_from="Zone"),
    }


"""
API: DescribeUDBType

获取UDB支持的类型信息
"""


class DescribeUDBTypeRequestSchema(schema.RequestSchema):
    """DescribeUDBType - 获取UDB支持的类型信息"""

    fields = {
        "BackupZone": fields.Str(required=False, dump_to="BackupZone"),
        "CompatibleWithDBType": fields.Str(
            required=False, dump_to="CompatibleWithDBType"
        ),
        "DBClusterType": fields.Str(required=False, dump_to="DBClusterType"),
        "DiskType": fields.Str(required=False, dump_to="DiskType"),
        "InstanceMode": fields.Str(required=False, dump_to="InstanceMode"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDBTypeResponseSchema(schema.ResponseSchema):
    """DescribeUDBType - 获取UDB支持的类型信息"""

    fields = {
        "DataSet": fields.List(
            models.UDBTypeSetSchema(), required=False, load_from="DataSet"
        ),
    }


"""
API: DisableUDBRWSplitting

关闭DB的读写分离功能
"""


class DisableUDBRWSplittingRequestSchema(schema.RequestSchema):
    """DisableUDBRWSplitting - 关闭DB的读写分离功能"""

    fields = {
        "MasterDBId": fields.Str(required=True, dump_to="MasterDBId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DisableUDBRWSplittingResponseSchema(schema.ResponseSchema):
    """DisableUDBRWSplitting - 关闭DB的读写分离功能"""

    fields = {}


"""
API: EditUDBBackupBlacklist

编辑UDB实例的备份黑名单
"""


class EditUDBBackupBlacklistRequestSchema(schema.RequestSchema):
    """EditUDBBackupBlacklist - 编辑UDB实例的备份黑名单"""

    fields = {
        "Blacklist": fields.Str(required=True, dump_to="Blacklist"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class EditUDBBackupBlacklistResponseSchema(schema.ResponseSchema):
    """EditUDBBackupBlacklist - 编辑UDB实例的备份黑名单"""

    fields = {}


"""
API: EnableUDBRWSplitting

开启DB的读写分离功能
"""


class EnableUDBRWSplittingRequestSchema(schema.RequestSchema):
    """EnableUDBRWSplitting - 开启DB的读写分离功能"""

    fields = {
        "BackupZone": fields.Str(required=False, dump_to="BackupZone"),
        "MasterDBId": fields.Str(required=True, dump_to="MasterDBId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class EnableUDBRWSplittingResponseSchema(schema.ResponseSchema):
    """EnableUDBRWSplitting - 开启DB的读写分离功能"""

    fields = {
        "MasterDBId": fields.Str(required=False, load_from="MasterDBId"),
        "RWIp": fields.Str(required=False, load_from="RWIp"),
    }


"""
API: ExtractUDBParamGroup

获取配置文件内容
"""


class ExtractUDBParamGroupRequestSchema(schema.RequestSchema):
    """ExtractUDBParamGroup - 获取配置文件内容"""

    fields = {
        "GroupId": fields.Int(required=True, dump_to="GroupId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RegionFlag": fields.Bool(required=False, dump_to="RegionFlag"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ExtractUDBParamGroupResponseSchema(schema.ResponseSchema):
    """ExtractUDBParamGroup - 获取配置文件内容"""

    fields = {
        "Content": fields.Str(required=True, load_from="Content"),
    }


"""
API: FetchUDBInstanceEarliestRecoverTime

获取UDB最早可回档的时间点
"""


class FetchUDBInstanceEarliestRecoverTimeRequestSchema(schema.RequestSchema):
    """FetchUDBInstanceEarliestRecoverTime - 获取UDB最早可回档的时间点"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class FetchUDBInstanceEarliestRecoverTimeResponseSchema(schema.ResponseSchema):
    """FetchUDBInstanceEarliestRecoverTime - 获取UDB最早可回档的时间点"""

    fields = {
        "EarliestTime": fields.Int(required=False, load_from="EarliestTime"),
    }


"""
API: GetUDBClientConnNum

输入一个DBID，能够获取客户端来源IP以及对应的连接数
"""


class GetUDBClientConnNumRequestSchema(schema.RequestSchema):
    """GetUDBClientConnNum - 输入一个DBID，能够获取客户端来源IP以及对应的连接数"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class GetUDBClientConnNumResponseSchema(schema.ResponseSchema):
    """GetUDBClientConnNum - 输入一个DBID，能够获取客户端来源IP以及对应的连接数"""

    fields = {
        "DataSet": fields.List(
            models.ConnNumMapSchema(), required=True, load_from="DataSet"
        ),
    }


"""
API: ModifyUDBInstanceName

重命名UDB实例
"""


class ModifyUDBInstanceNameRequestSchema(schema.RequestSchema):
    """ModifyUDBInstanceName - 重命名UDB实例"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ModifyUDBInstanceNameResponseSchema(schema.ResponseSchema):
    """ModifyUDBInstanceName - 重命名UDB实例"""

    fields = {}


"""
API: ModifyUDBInstancePassword

修改DB实例的管理员密码
"""


class ModifyUDBInstancePasswordRequestSchema(schema.RequestSchema):
    """ModifyUDBInstancePassword - 修改DB实例的管理员密码"""

    fields = {
        "AccountName": fields.Str(required=False, dump_to="AccountName"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ModifyUDBInstancePasswordResponseSchema(schema.ResponseSchema):
    """ModifyUDBInstancePassword - 修改DB实例的管理员密码"""

    fields = {}


"""
API: PromoteUDBInstanceToHA

普通db升级为高可用(只针对mysql5.5及以上版本SSD机型的实例)  ，对于NVMe机型的单点升级高可用，虽然也能使用该操作再加上SwitchUDBInstanceToHA，但是更建议直接调用新的API接口（UpgradeUDBInstanceToHA）
"""


class PromoteUDBInstanceToHARequestSchema(schema.RequestSchema):
    """PromoteUDBInstanceToHA - 普通db升级为高可用(只针对mysql5.5及以上版本SSD机型的实例)  ，对于NVMe机型的单点升级高可用，虽然也能使用该操作再加上SwitchUDBInstanceToHA，但是更建议直接调用新的API接口（UpgradeUDBInstanceToHA）"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class PromoteUDBInstanceToHAResponseSchema(schema.ResponseSchema):
    """PromoteUDBInstanceToHA - 普通db升级为高可用(只针对mysql5.5及以上版本SSD机型的实例)  ，对于NVMe机型的单点升级高可用，虽然也能使用该操作再加上SwitchUDBInstanceToHA，但是更建议直接调用新的API接口（UpgradeUDBInstanceToHA）"""

    fields = {}


"""
API: PromoteUDBSlave

从库提升为独立库
"""


class PromoteUDBSlaveRequestSchema(schema.RequestSchema):
    """PromoteUDBSlave - 从库提升为独立库"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "IsForce": fields.Bool(required=False, dump_to="IsForce"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class PromoteUDBSlaveResponseSchema(schema.ResponseSchema):
    """PromoteUDBSlave - 从库提升为独立库"""

    fields = {}


"""
API: ResizeUDBInstance

修改（升级和降级）UDB实例的配置，包括内存和磁盘的配置，对于内存升级无需关闭实例，其他场景需要事先关闭实例。两套参数可以配置升降机：1.配置UseSSD和SSDType  2.配置InstanceType，不需要配置InstanceMode。这两套第二套参数的优先级更高
"""


class ResizeUDBInstanceRequestSchema(schema.RequestSchema):
    """ResizeUDBInstance - 修改（升级和降级）UDB实例的配置，包括内存和磁盘的配置，对于内存升级无需关闭实例，其他场景需要事先关闭实例。两套参数可以配置升降机：1.配置UseSSD和SSDType  2.配置InstanceType，不需要配置InstanceMode。这两套第二套参数的优先级更高"""

    fields = {
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "DiskSpace": fields.Int(required=True, dump_to="DiskSpace"),
        "InstanceMode": fields.Str(required=False, dump_to="InstanceMode"),
        "InstanceType": fields.Str(required=False, dump_to="InstanceType"),
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SSDType": fields.Str(required=False, dump_to="SSDType"),
        "StartAfterUpgrade": fields.Bool(
            required=False, dump_to="StartAfterUpgrade"
        ),
        "UDBCId": fields.Str(required=False, dump_to="UDBCId"),
        "UseSSD": fields.Bool(required=False, dump_to="UseSSD"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class ResizeUDBInstanceResponseSchema(schema.ResponseSchema):
    """ResizeUDBInstance - 修改（升级和降级）UDB实例的配置，包括内存和磁盘的配置，对于内存升级无需关闭实例，其他场景需要事先关闭实例。两套参数可以配置升降机：1.配置UseSSD和SSDType  2.配置InstanceType，不需要配置InstanceMode。这两套第二套参数的优先级更高"""

    fields = {}


"""
API: RestartRWSplitting

读写分离中间件重启，对应docker重启，但是ip不变
"""


class RestartRWSplittingRequestSchema(schema.RequestSchema):
    """RestartRWSplitting - 读写分离中间件重启，对应docker重启，但是ip不变"""

    fields = {
        "MasterDBId": fields.Str(required=True, dump_to="MasterDBId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class RestartRWSplittingResponseSchema(schema.ResponseSchema):
    """RestartRWSplitting - 读写分离中间件重启，对应docker重启，但是ip不变"""

    fields = {}


"""
API: RestartUDBInstance

重启UDB实例
"""


class RestartUDBInstanceRequestSchema(schema.RequestSchema):
    """RestartUDBInstance - 重启UDB实例"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class RestartUDBInstanceResponseSchema(schema.ResponseSchema):
    """RestartUDBInstance - 重启UDB实例"""

    fields = {}


"""
API: SetUDBRWSplitting

设置读写分离的模式
"""


class SetUDBRWSplittingRequestSchema(schema.RequestSchema):
    """SetUDBRWSplitting - 设置读写分离的模式"""

    fields = {
        "DBIds": fields.List(fields.Str()),
        "DelayThreshold": fields.Int(required=False, dump_to="DelayThreshold"),
        "MasterDBId": fields.Str(required=True, dump_to="MasterDBId"),
        "ReadModel": fields.Str(required=True, dump_to="ReadModel"),
        "ReadPercents": fields.List(fields.Str()),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class SetUDBRWSplittingResponseSchema(schema.ResponseSchema):
    """SetUDBRWSplitting - 设置读写分离的模式"""

    fields = {}


"""
API: StartUDBInstance

启动UDB实例
"""


class StartUDBInstanceRequestSchema(schema.RequestSchema):
    """StartUDBInstance - 启动UDB实例"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class StartUDBInstanceResponseSchema(schema.ResponseSchema):
    """StartUDBInstance - 启动UDB实例"""

    fields = {}


"""
API: StopUDBInstance

关闭UDB实例
"""


class StopUDBInstanceRequestSchema(schema.RequestSchema):
    """StopUDBInstance - 关闭UDB实例"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ForceToKill": fields.Bool(required=False, dump_to="ForceToKill"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class StopUDBInstanceResponseSchema(schema.ResponseSchema):
    """StopUDBInstance - 关闭UDB实例"""

    fields = {}


"""
API: SwitchUDBHAToSentinel

UDB高可用实例从HAProxy版本升级为Sentinel版本（不带HAProxy）升级耗时5-10秒
"""


class SwitchUDBHAToSentinelRequestSchema(schema.RequestSchema):
    """SwitchUDBHAToSentinel - UDB高可用实例从HAProxy版本升级为Sentinel版本（不带HAProxy）升级耗时5-10秒"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ForceSwitch": fields.Bool(required=False, dump_to="ForceSwitch"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class SwitchUDBHAToSentinelResponseSchema(schema.ResponseSchema):
    """SwitchUDBHAToSentinel - UDB高可用实例从HAProxy版本升级为Sentinel版本（不带HAProxy）升级耗时5-10秒"""

    fields = {}


"""
API: SwitchUDBInstanceToHA

普通UDB切换为高可用(只针对mysql5.5及以上版本SSD机型的实例) ，原db状态为WaitForSwitch时，调用该api； 对于NVMe机型的单点升级高可用，虽然也能使用PromoteUDBInstanceToHA再加上该操作，但是更建议直接调用新的API接口（UpgradeUDBInstanceToHA）
"""


class SwitchUDBInstanceToHARequestSchema(schema.RequestSchema):
    """SwitchUDBInstanceToHA - 普通UDB切换为高可用(只针对mysql5.5及以上版本SSD机型的实例) ，原db状态为WaitForSwitch时，调用该api； 对于NVMe机型的单点升级高可用，虽然也能使用PromoteUDBInstanceToHA再加上该操作，但是更建议直接调用新的API接口（UpgradeUDBInstanceToHA）"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Str(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
    }


class SwitchUDBInstanceToHAResponseSchema(schema.ResponseSchema):
    """SwitchUDBInstanceToHA - 普通UDB切换为高可用(只针对mysql5.5及以上版本SSD机型的实例) ，原db状态为WaitForSwitch时，调用该api； 对于NVMe机型的单点升级高可用，虽然也能使用PromoteUDBInstanceToHA再加上该操作，但是更建议直接调用新的API接口（UpgradeUDBInstanceToHA）"""

    fields = {
        "DBId": fields.Str(required=False, load_from="DBId"),
    }


"""
API: UpdateUDBInstanceBackupStrategy

修改UDB自动备份策略
"""


class UpdateUDBInstanceBackupStrategyRequestSchema(schema.RequestSchema):
    """UpdateUDBInstanceBackupStrategy - 修改UDB自动备份策略"""

    fields = {
        "BackupDate": fields.Str(required=False, dump_to="BackupDate"),
        "BackupMethod": fields.Str(required=False, dump_to="BackupMethod"),
        "BackupTime": fields.Int(required=False, dump_to="BackupTime"),
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ForceDump": fields.Bool(required=False, dump_to="ForceDump"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class UpdateUDBInstanceBackupStrategyResponseSchema(schema.ResponseSchema):
    """UpdateUDBInstanceBackupStrategy - 修改UDB自动备份策略"""

    fields = {}


"""
API: UpdateUDBInstanceSlaveBackupSwitch

开启或者关闭UDB从库备份
"""


class UpdateUDBInstanceSlaveBackupSwitchRequestSchema(schema.RequestSchema):
    """UpdateUDBInstanceSlaveBackupSwitch - 开启或者关闭UDB从库备份"""

    fields = {
        "BackupSwitch": fields.Int(required=True, dump_to="BackupSwitch"),
        "MasterDBId": fields.Str(required=True, dump_to="MasterDBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SlaveDBId": fields.Str(required=False, dump_to="SlaveDBId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class UpdateUDBInstanceSlaveBackupSwitchResponseSchema(schema.ResponseSchema):
    """UpdateUDBInstanceSlaveBackupSwitch - 开启或者关闭UDB从库备份"""

    fields = {}


"""
API: UpdateUDBParamGroup

更新UDB配置参数项
"""


class UpdateUDBParamGroupRequestSchema(schema.RequestSchema):
    """UpdateUDBParamGroup - 更新UDB配置参数项"""

    fields = {
        "Description": fields.Str(required=False, dump_to="Description"),
        "GroupId": fields.Int(required=True, dump_to="GroupId"),
        "Key": fields.Str(required=False, dump_to="Key"),
        "Name": fields.Str(required=False, dump_to="Name"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RegionFlag": fields.Bool(required=False, dump_to="RegionFlag"),
        "Value": fields.Str(required=False, dump_to="Value"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class UpdateUDBParamGroupResponseSchema(schema.ResponseSchema):
    """UpdateUDBParamGroup - 更新UDB配置参数项"""

    fields = {}


"""
API: UpgradeUDBInstanceToHA

快杰普通db升级为高可用(只针对mysql5.5及以上版本Nvme机型的实例)  
"""


class UpgradeUDBInstanceToHARequestSchema(schema.RequestSchema):
    """UpgradeUDBInstanceToHA - 快杰普通db升级为高可用(只针对mysql5.5及以上版本Nvme机型的实例)"""

    fields = {
        "DBId": fields.Str(required=True, dump_to="DBId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class UpgradeUDBInstanceToHAResponseSchema(schema.ResponseSchema):
    """UpgradeUDBInstanceToHA - 快杰普通db升级为高可用(只针对mysql5.5及以上版本Nvme机型的实例)"""

    fields = {}


"""
API: UploadUDBParamGroup

导入UDB配置
"""


class UploadUDBParamGroupRequestSchema(schema.RequestSchema):
    """UploadUDBParamGroup - 导入UDB配置"""

    fields = {
        "Content": fields.Str(required=True, dump_to="Content"),
        "DBTypeId": fields.Str(required=True, dump_to="DBTypeId"),
        "Description": fields.Str(required=True, dump_to="Description"),
        "GroupName": fields.Str(required=True, dump_to="GroupName"),
        "ParamGroupTypeId": fields.Int(
            required=False, dump_to="ParamGroupTypeId"
        ),  # Deprecated, will be removed at 1.0
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RegionFlag": fields.Bool(required=False, dump_to="RegionFlag"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class UploadUDBParamGroupResponseSchema(schema.ResponseSchema):
    """UploadUDBParamGroup - 导入UDB配置"""

    fields = {
        "GroupId": fields.Int(required=False, load_from="GroupId"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.ufile.schemas import models

""" UFile API Schema
"""


"""
API: CreateBucket

创建Bucket
"""


class CreateBucketRequestSchema(schema.RequestSchema):
    """CreateBucket - 创建Bucket"""

    fields = {
        "BucketName": fields.Str(required=True, dump_to="BucketName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Type": fields.Str(required=False, dump_to="Type"),
    }


class CreateBucketResponseSchema(schema.ResponseSchema):
    """CreateBucket - 创建Bucket"""

    fields = {
        "BucketId": fields.Str(required=False, load_from="BucketId"),
        "BucketName": fields.Str(required=False, load_from="BucketName"),
    }


"""
API: CreateUFileLifeCycle

创建生命周期管理
"""


class CreateUFileLifeCycleRequestSchema(schema.RequestSchema):
    """CreateUFileLifeCycle - 创建生命周期管理"""

    fields = {
        "ArchivalDays": fields.Int(required=False, dump_to="ArchivalDays"),
        "BucketName": fields.Str(required=True, dump_to="BucketName"),
        "Days": fields.Int(required=False, dump_to="Days"),
        "IADays": fields.Int(required=False, dump_to="IADays"),
        "LifeCycleName": fields.Str(required=True, dump_to="LifeCycleName"),
        "Prefix": fields.Str(required=True, dump_to="Prefix"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "Status": fields.Str(required=True, dump_to="Status"),
    }


class CreateUFileLifeCycleResponseSchema(schema.ResponseSchema):
    """CreateUFileLifeCycle - 创建生命周期管理"""

    fields = {
        "LifeCycleId": fields.Str(required=True, load_from="LifeCycleId"),
    }


"""
API: CreateUFileToken

创建US3令牌
"""


class CreateUFileTokenRequestSchema(schema.RequestSchema):
    """CreateUFileToken - 创建US3令牌"""

    fields = {
        "AllowedBuckets": fields.List(fields.Str()),
        "AllowedOps": fields.List(fields.Str()),
        "AllowedPrefixes": fields.List(fields.Str()),
        "BlackIPList": fields.List(fields.Str()),
        "ExpireTime": fields.Int(required=False, dump_to="ExpireTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "TokenName": fields.Str(required=True, dump_to="TokenName"),
        "WhiteIPList": fields.List(fields.Str()),
    }


class CreateUFileTokenResponseSchema(schema.ResponseSchema):
    """CreateUFileToken - 创建US3令牌"""

    fields = {
        "TokenId": fields.Str(required=False, load_from="TokenId"),
        "UFileTokenSet": models.UFileTokenSetSchema(),
    }


"""
API: DeleteBucket

删除Bucket
"""


class DeleteBucketRequestSchema(schema.RequestSchema):
    """DeleteBucket - 删除Bucket"""

    fields = {
        "BucketName": fields.Str(required=True, dump_to="BucketName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
    }


class DeleteBucketResponseSchema(schema.ResponseSchema):
    """DeleteBucket - 删除Bucket"""

    fields = {
        "BucketId": fields.Str(required=False, load_from="BucketId"),
        "BucketName": fields.Str(required=False, load_from="BucketName"),
    }


"""
API: DeleteUFileLifeCycle

删除生命周期管理
"""


class DeleteUFileLifeCycleRequestSchema(schema.RequestSchema):
    """DeleteUFileLifeCycle - 删除生命周期管理"""

    fields = {
        "BucketName": fields.Str(required=True, dump_to="BucketName"),
        "LifeCycleId": fields.Str(required=True, dump_to="LifeCycleId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
    }


class DeleteUFileLifeCycleResponseSchema(schema.ResponseSchema):
    """DeleteUFileLifeCycle - 删除生命周期管理"""

    fields = {}


"""
API: DeleteUFileToken

删除令牌
"""


class DeleteUFileTokenRequestSchema(schema.RequestSchema):
    """DeleteUFileToken - 删除令牌"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "TokenId": fields.Str(required=True, dump_to="TokenId"),
    }


class DeleteUFileTokenResponseSchema(schema.ResponseSchema):
    """DeleteUFileToken - 删除令牌"""

    fields = {}


"""
API: DescribeBucket

获取Bucket的描述信息
"""


class DescribeBucketRequestSchema(schema.RequestSchema):
    """DescribeBucket - 获取Bucket的描述信息"""

    fields = {
        "BucketName": fields.Str(required=False, dump_to="BucketName"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
    }


class DescribeBucketResponseSchema(schema.ResponseSchema):
    """DescribeBucket - 获取Bucket的描述信息"""

    fields = {
        "DataSet": fields.List(
            models.UFileBucketSetSchema(), required=False, load_from="DataSet"
        ),
    }


"""
API: DescribeUFileLifeCycle

获取生命周期信息
"""


class DescribeUFileLifeCycleRequestSchema(schema.RequestSchema):
    """DescribeUFileLifeCycle - 获取生命周期信息"""

    fields = {
        "BucketName": fields.Str(required=True, dump_to="BucketName"),
        "LifeCycleId": fields.Str(required=False, dump_to="LifeCycleId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
    }


class DescribeUFileLifeCycleResponseSchema(schema.ResponseSchema):
    """DescribeUFileLifeCycle - 获取生命周期信息"""

    fields = {
        "DateSet": fields.List(
            models.LifeCycleItemSchema(), required=True, load_from="DateSet"
        ),
    }


"""
API: DescribeUFileToken

获取令牌信息
"""


class DescribeUFileTokenRequestSchema(schema.RequestSchema):
    """DescribeUFileToken - 获取令牌信息"""

    fields = {
        "Display": fields.Int(required=False, dump_to="Display"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "TokenId": fields.Str(required=False, dump_to="TokenId"),
        "TokenName": fields.Str(required=False, dump_to="TokenName"),
    }


class DescribeUFileTokenResponseSchema(schema.ResponseSchema):
    """DescribeUFileToken - 获取令牌信息"""

    fields = {
        "DataSet": fields.List(
            models.UFileTokenSetSchema(), required=True, load_from="DataSet"
        ),
    }


"""
API: GetUFileDailyReport

查看日消费报表
"""


class GetUFileDailyReportRequestSchema(schema.RequestSchema):
    """GetUFileDailyReport - 查看日消费报表"""

    fields = {
        "BucketName": fields.Str(required=False, dump_to="BucketName"),
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "StartTime": fields.Int(required=True, dump_to="StartTime"),
    }


class GetUFileDailyReportResponseSchema(schema.ResponseSchema):
    """GetUFileDailyReport - 查看日消费报表"""

    fields = {
        "DataSet": fields.List(
            models.UFileReportItemSchema(), required=True, load_from="DataSet"
        ),
    }


"""
API: GetUFileQuota

查看配额状态
"""


class GetUFileQuotaRequestSchema(schema.RequestSchema):
    """GetUFileQuota - 查看配额状态"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "QuotaType": fields.Str(required=True, dump_to="QuotaType"),
    }


class GetUFileQuotaResponseSchema(schema.ResponseSchema):
    """GetUFileQuota - 查看配额状态"""

    fields = {
        "LeftQuota": fields.Float(required=False, load_from="LeftQuota"),
    }


"""
API: GetUFileQuotaInfo

获取配额信息
"""


class GetUFileQuotaInfoRequestSchema(schema.RequestSchema):
    """GetUFileQuotaInfo - 获取配额信息"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "QuotaType": fields.List(fields.Str()),
        "Region": fields.Str(required=True, dump_to="Region"),
    }


class GetUFileQuotaInfoResponseSchema(schema.ResponseSchema):
    """GetUFileQuotaInfo - 获取配额信息"""

    fields = {
        "DataSet": fields.List(
            models.UFileQuotaDataSetItemSchema(),
            required=False,
            load_from="DataSet",
        ),
    }


"""
API: GetUFileQuotaPrice

根据US3的购买配额，查询需要支付的价格。
"""


class GetUFileQuotaPriceRequestSchema(schema.RequestSchema):
    """GetUFileQuotaPrice - 根据US3的购买配额，查询需要支付的价格。"""

    fields = {
        "DownloadTraffic": fields.Int(
            required=False, dump_to="DownloadTraffic"
        ),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RequestCount": fields.Int(required=False, dump_to="RequestCount"),
        "StorageVolume": fields.Int(required=False, dump_to="StorageVolume"),
    }


class GetUFileQuotaPriceResponseSchema(schema.ResponseSchema):
    """GetUFileQuotaPrice - 根据US3的购买配额，查询需要支付的价格。"""

    fields = {
        "Price": fields.Float(required=False, load_from="Price"),
    }


"""
API: GetUFileReport

查看配额使用报表
"""


class GetUFileReportRequestSchema(schema.RequestSchema):
    """GetUFileReport - 查看配额使用报表"""

    fields = {
        "EndTime": fields.Int(required=True, dump_to="EndTime"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "StartTime": fields.Int(required=True, dump_to="StartTime"),
    }


class GetUFileReportResponseSchema(schema.ResponseSchema):
    """GetUFileReport - 查看配额使用报表"""

    fields = {
        "DataSet": fields.List(
            models.UFileReportSetSchema(), required=False, load_from="DataSet"
        ),
    }


"""
API: SetUFileReferer

设置对象存储防盗链
"""


class SetUFileRefererRequestSchema(schema.RequestSchema):
    """SetUFileReferer - 设置对象存储防盗链"""

    fields = {
        "BucketName": fields.Str(required=True, dump_to="BucketName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "RefererAllowNull": fields.Bool(
            required=False, dump_to="RefererAllowNull"
        ),
        "RefererStatus": fields.Str(required=True, dump_to="RefererStatus"),
        "RefererType": fields.Int(required=False, dump_to="RefererType"),
        "Referers": fields.List(fields.Str()),
        "Region": fields.Str(required=False, dump_to="Region"),
    }


class SetUFileRefererResponseSchema(schema.ResponseSchema):
    """SetUFileReferer - 设置对象存储防盗链"""

    fields = {}


"""
API: UpdateBucket

更改Bucket的属性
"""


class UpdateBucketRequestSchema(schema.RequestSchema):
    """UpdateBucket - 更改Bucket的属性"""

    fields = {
        "BucketName": fields.Str(required=True, dump_to="BucketName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Type": fields.Str(required=True, dump_to="Type"),
    }


class UpdateBucketResponseSchema(schema.ResponseSchema):
    """UpdateBucket - 更改Bucket的属性"""

    fields = {
        "BucketId": fields.Str(required=False, load_from="BucketId"),
        "BucketName": fields.Str(required=False, load_from="BucketName"),
    }


"""
API: UpdateUFileLifeCycle

更新生命周期管理
"""


class UpdateUFileLifeCycleRequestSchema(schema.RequestSchema):
    """UpdateUFileLifeCycle - 更新生命周期管理"""

    fields = {
        "ArchivalDays": fields.Int(required=False, dump_to="ArchivalDays"),
        "BucketName": fields.Str(required=True, dump_to="BucketName"),
        "Days": fields.Int(required=False, dump_to="Days"),
        "IADays": fields.Int(required=False, dump_to="IADays"),
        "LifeCycleId": fields.Str(required=True, dump_to="LifeCycleId"),
        "LifeCycleName": fields.Str(required=True, dump_to="LifeCycleName"),
        "Prefix": fields.Str(required=True, dump_to="Prefix"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "Status": fields.Str(required=True, dump_to="Status"),
    }


class UpdateUFileLifeCycleResponseSchema(schema.ResponseSchema):
    """UpdateUFileLifeCycle - 更新生命周期管理"""

    fields = {}


"""
API: UpdateUFileToken

更新令牌的操作权限，可操作key的前缀，可操作bucket和令牌超时时间点
"""


class UpdateUFileTokenRequestSchema(schema.RequestSchema):
    """UpdateUFileToken - 更新令牌的操作权限，可操作key的前缀，可操作bucket和令牌超时时间点"""

    fields = {
        "AllowedBuckets": fields.List(fields.Str()),
        "AllowedOps": fields.List(fields.Str()),
        "AllowedPrefixes": fields.List(fields.Str()),
        "ExpireTime": fields.Int(required=False, dump_to="ExpireTime"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "TokenId": fields.Str(required=True, dump_to="TokenId"),
        "TokenName": fields.Str(required=False, dump_to="TokenName"),
    }


class UpdateUFileTokenResponseSchema(schema.ResponseSchema):
    """UpdateUFileToken - 更新令牌的操作权限，可操作key的前缀，可操作bucket和令牌超时时间点"""

    fields = {}


"""
API: UpdateUdsRule

针对对象存储的文件，进行自动触发解压。
"""


class UpdateUdsRuleRequestSchema(schema.RequestSchema):
    """UpdateUdsRule - 针对对象存储的文件，进行自动触发解压。"""

    fields = {
        "ContactGroupId": fields.Str(required=False, dump_to="ContactGroupId"),
        "DstBucket": fields.Str(required=True, dump_to="DstBucket"),
        "DstDirectory": fields.Str(required=True, dump_to="DstDirectory"),
        "DstTokenId": fields.Str(required=True, dump_to="DstTokenId"),
        "Events": fields.List(fields.Str()),
        "KeepUS3Name": fields.Bool(required=True, dump_to="KeepUS3Name"),
        "NotificationTypes": fields.List(fields.Str()),
        "Ops": fields.List(fields.Str()),
        "Prefixes": fields.Str(required=True, dump_to="Prefixes"),
        "RuleId": fields.Str(required=True, dump_to="RuleId"),
        "RuleName": fields.Str(required=True, dump_to="RuleName"),
        "SrcBucket": fields.Str(required=True, dump_to="SrcBucket"),
        "SrcTokenId": fields.Str(required=True, dump_to="SrcTokenId"),
    }


class UpdateUdsRuleResponseSchema(schema.ResponseSchema):
    """UpdateUdsRule - 针对对象存储的文件，进行自动触发解压。"""

    fields = {
        "Mesage": fields.Str(required=False, load_from="Mesage"),
        "RuleId": fields.Str(required=True, load_from="RuleId"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.uddb.schemas import models

""" UDDB API Schema
"""


"""
API: ChangeUDDBInstanceName

修改分布式数据库中间件名称
"""


class ChangeUDDBInstanceNameRequestSchema(schema.RequestSchema):
    """ChangeUDDBInstanceName - 修改分布式数据库中间件名称"""

    fields = {
        "NewName": fields.Str(required=True, dump_to="NewName"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class ChangeUDDBInstanceNameResponseSchema(schema.ResponseSchema):
    """ChangeUDDBInstanceName - 修改分布式数据库中间件名称"""

    fields = {}


"""
API: ChangeUDDBSlaveCount

改变分布式数据库数据节点的只读实例个数
每一个UDDB的数据节点负责处理所有的写入请求。与此同时，每一个数据节点可以配置若干个该节点的只读实例。当主节点的数据写入完毕后，只读实例把这次的写入操作进行更新，从而和数据节点保持一致。
只读实例可以使得数据由多份复制，在数据节点和只读实例之间，可以做请求的读写分离, 也就是说, 主节点写入数据之后, 数据的读操作可以由数据只读实例进行分担, 这样减少主节点的压力, 增加性能
当改变了数据节点的只读实例个数之后，对于现有的和以后的每一个数据节点都采用这个配置。如果UDDB实例有现有的数据节点, 那么它会根据新配置的参数，自动创建或删除数据节点的只读实例
如下状态的UDDB实例可以进行这个操作:
Running: 系统正常运行中
当请求返回成功之后，UDDB实例的状态变成"ChangingSlaveCount"; 如果返回失败, UDDB实例状态保持不变 当UDDB更改数据分区的只读实例个数成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果更改过程中出现异常, 状态变成"Abnormal"(异常运行中)或者"Error"(运行错误)
"""


class ChangeUDDBSlaveCountRequestSchema(schema.RequestSchema):
    """ChangeUDDBSlaveCount - 改变分布式数据库数据节点的只读实例个数
    每一个UDDB的数据节点负责处理所有的写入请求。与此同时，每一个数据节点可以配置若干个该节点的只读实例。当主节点的数据写入完毕后，只读实例把这次的写入操作进行更新，从而和数据节点保持一致。
    只读实例可以使得数据由多份复制，在数据节点和只读实例之间，可以做请求的读写分离, 也就是说, 主节点写入数据之后, 数据的读操作可以由数据只读实例进行分担, 这样减少主节点的压力, 增加性能
    当改变了数据节点的只读实例个数之后，对于现有的和以后的每一个数据节点都采用这个配置。如果UDDB实例有现有的数据节点, 那么它会根据新配置的参数，自动创建或删除数据节点的只读实例
    如下状态的UDDB实例可以进行这个操作:
    Running: 系统正常运行中
    当请求返回成功之后，UDDB实例的状态变成"ChangingSlaveCount"; 如果返回失败, UDDB实例状态保持不变 当UDDB更改数据分区的只读实例个数成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果更改过程中出现异常, 状态变成"Abnormal"(异常运行中)或者"Error"(运行错误)
    """

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SlaveCount": fields.Str(required=True, dump_to="SlaveCount"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class ChangeUDDBSlaveCountResponseSchema(schema.ResponseSchema):
    """ChangeUDDBSlaveCount - 改变分布式数据库数据节点的只读实例个数
    每一个UDDB的数据节点负责处理所有的写入请求。与此同时，每一个数据节点可以配置若干个该节点的只读实例。当主节点的数据写入完毕后，只读实例把这次的写入操作进行更新，从而和数据节点保持一致。
    只读实例可以使得数据由多份复制，在数据节点和只读实例之间，可以做请求的读写分离, 也就是说, 主节点写入数据之后, 数据的读操作可以由数据只读实例进行分担, 这样减少主节点的压力, 增加性能
    当改变了数据节点的只读实例个数之后，对于现有的和以后的每一个数据节点都采用这个配置。如果UDDB实例有现有的数据节点, 那么它会根据新配置的参数，自动创建或删除数据节点的只读实例
    如下状态的UDDB实例可以进行这个操作:
    Running: 系统正常运行中
    当请求返回成功之后，UDDB实例的状态变成"ChangingSlaveCount"; 如果返回失败, UDDB实例状态保持不变 当UDDB更改数据分区的只读实例个数成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果更改过程中出现异常, 状态变成"Abnormal"(异常运行中)或者"Error"(运行错误)
    """

    fields = {}


"""
API: CreateUDDBInstance

创建创建分布式数据库UDDB实例, 简称UDDB实例。
"""


class CreateUDDBInstanceRequestSchema(schema.RequestSchema):
    """CreateUDDBInstance - 创建创建分布式数据库UDDB实例, 简称UDDB实例。"""

    fields = {
        "AdminPassword": fields.Str(required=True, dump_to="AdminPassword"),
        "AdminUser": fields.Str(required=False, dump_to="AdminUser"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "DBTypeId": fields.Str(required=True, dump_to="DBTypeId"),
        "DataNodeCount": fields.Int(required=True, dump_to="DataNodeCount"),
        "DataNodeDiskSpace": fields.Int(
            required=True, dump_to="DataNodeDiskSpace"
        ),
        "DataNodeMemory": fields.Int(required=True, dump_to="DataNodeMemory"),
        "DataNodeSlaveCount": fields.Int(
            required=False, dump_to="DataNodeSlaveCount"
        ),
        "InstanceMode": fields.Str(required=False, dump_to="InstanceMode"),
        "InstanceType": fields.Str(required=False, dump_to="InstanceType"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "Port": fields.Int(required=False, dump_to="Port"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouterNodeNum": fields.Int(required=True, dump_to="RouterNodeNum"),
        "RouterVersion": fields.Str(required=True, dump_to="RouterVersion"),
        "SubnetId": fields.Str(required=False, dump_to="SubnetId"),
        "VPCId": fields.Str(required=False, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUDDBInstanceResponseSchema(schema.ResponseSchema):
    """CreateUDDBInstance - 创建创建分布式数据库UDDB实例, 简称UDDB实例。"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
        "UDDBId": fields.Str(required=False, load_from="UDDBId"),
    }


"""
API: DeleteUDDBInstance

删除UDDB实例。
如下状态的UDDB实例可以进行这个操作:
InitFail: 初始化失败
Shutoff: 已关闭
当请求返回成功之后，UDDB实例就已经被删除, 列表上看不到对应的UDDB实例
"""


class DeleteUDDBInstanceRequestSchema(schema.RequestSchema):
    """DeleteUDDBInstance - 删除UDDB实例。
    如下状态的UDDB实例可以进行这个操作:
    InitFail: 初始化失败
    Shutoff: 已关闭
    当请求返回成功之后，UDDB实例就已经被删除, 列表上看不到对应的UDDB实例
    """

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteUDDBInstanceResponseSchema(schema.ResponseSchema):
    """DeleteUDDBInstance - 删除UDDB实例。
    如下状态的UDDB实例可以进行这个操作:
    InitFail: 初始化失败
    Shutoff: 已关闭
    当请求返回成功之后，UDDB实例就已经被删除, 列表上看不到对应的UDDB实例
    """

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: DescribeUDDBInstance

获取分布式数据库UDDB的详细信息
"""


class DescribeUDDBInstanceRequestSchema(schema.RequestSchema):
    """DescribeUDDBInstance - 获取分布式数据库UDDB的详细信息"""

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDDBInstanceResponseSchema(schema.ResponseSchema):
    """DescribeUDDBInstance - 获取分布式数据库UDDB的详细信息"""

    fields = {
        "DataSet": fields.List(
            models.DataSetUDDBSchema(), required=False, load_from="DataSet"
        ),
        "Message": fields.Str(required=False, load_from="Message"),
    }


"""
API: DescribeUDDBInstancePrice

获取分布式数据库UDDB价格
"""


class DescribeUDDBInstancePriceRequestSchema(schema.RequestSchema):
    """DescribeUDDBInstancePrice - 获取分布式数据库UDDB价格"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "DataNodeCount": fields.Int(required=True, dump_to="DataNodeCount"),
        "DataNodeDiskSpace": fields.Int(
            required=True, dump_to="DataNodeDiskSpace"
        ),
        "DataNodeMemory": fields.Str(required=True, dump_to="DataNodeMemory"),
        "DataNodeSlaveCount": fields.Int(
            required=False, dump_to="DataNodeSlaveCount"
        ),
        "InstanceMode": fields.Str(required=False, dump_to="InstanceMode"),
        "InstanceType": fields.Str(required=False, dump_to="InstanceType"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouterNodeNum": fields.Int(required=True, dump_to="RouterNodeNum"),
        "RouterVersion": fields.Str(required=True, dump_to="RouterVersion"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDDBInstancePriceResponseSchema(schema.ResponseSchema):
    """DescribeUDDBInstancePrice - 获取分布式数据库UDDB价格"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
        "PriceInfo": models.PriceDetailInfoSchema(),
    }


"""
API: DescribeUDDBInstanceUpgradePrice

升级UDDB时，获取升级后的价格
"""


class DescribeUDDBInstanceUpgradePriceRequestSchema(schema.RequestSchema):
    """DescribeUDDBInstanceUpgradePrice - 升级UDDB时，获取升级后的价格"""

    fields = {
        "DataNodeCount": fields.Int(required=False, dump_to="DataNodeCount"),
        "DataNodeDiskSpace": fields.Int(
            required=False, dump_to="DataNodeDiskSpace"
        ),
        "DataNodeMemory": fields.Int(required=False, dump_to="DataNodeMemory"),
        "DataNodeSlaveCount": fields.Int(
            required=False, dump_to="DataNodeSlaveCount"
        ),
        "InstanceMode": fields.Str(required=False, dump_to="InstanceMode"),
        "InstanceType": fields.Str(required=False, dump_to="InstanceType"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouterNodeNum": fields.Int(required=True, dump_to="RouterNodeNum"),
        "RouterVersion": fields.Str(required=True, dump_to="RouterVersion"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUDDBInstanceUpgradePriceResponseSchema(schema.ResponseSchema):
    """DescribeUDDBInstanceUpgradePrice - 升级UDDB时，获取升级后的价格"""

    fields = {
        "Message": fields.Str(required=False, load_from="Message"),
        "PriceInfo": models.PriceInfoSchema(),
    }


"""
API: RestartUDDBInstance

重启UDDB实例，开始提供服务。

如下状态的UDDB实例可以进行这个操作:

Running: 正常运行中
Abnormal: 异常运行中
当请求返回成功之后，UDDB实例的状态变成"Starting"(启动中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在重启过程中, 当UDDB实例启动成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果启动过程中出现异常, 状态变成"Abnormal"(异常运行中), 或者"Shutoff"(已关闭
"""


class RestartUDDBInstanceRequestSchema(schema.RequestSchema):
    """RestartUDDBInstance - 重启UDDB实例，开始提供服务。

    如下状态的UDDB实例可以进行这个操作:

    Running: 正常运行中
    Abnormal: 异常运行中
    当请求返回成功之后，UDDB实例的状态变成"Starting"(启动中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在重启过程中, 当UDDB实例启动成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果启动过程中出现异常, 状态变成"Abnormal"(异常运行中), 或者"Shutoff"(已关闭
    """

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class RestartUDDBInstanceResponseSchema(schema.ResponseSchema):
    """RestartUDDBInstance - 重启UDDB实例，开始提供服务。

    如下状态的UDDB实例可以进行这个操作:

    Running: 正常运行中
    Abnormal: 异常运行中
    当请求返回成功之后，UDDB实例的状态变成"Starting"(启动中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在重启过程中, 当UDDB实例启动成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果启动过程中出现异常, 状态变成"Abnormal"(异常运行中), 或者"Shutoff"(已关闭
    """

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: StartUDDBInstance

启动UDDB实例，开始提供服务。

如下状态的UDDB实例可以进行这个操作:

Shutoff: 已关闭
当请求返回成功之后，UDDB实例的状态变成"Starting"(启动中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在启动过程中, 当UDDB实例启动成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果启动过程中出现异常, 状态变成"Abnormal"(异常运行中), 或者"Shutoff"(已关闭)
"""


class StartUDDBInstanceRequestSchema(schema.RequestSchema):
    """StartUDDBInstance - 启动UDDB实例，开始提供服务。

    如下状态的UDDB实例可以进行这个操作:

    Shutoff: 已关闭
    当请求返回成功之后，UDDB实例的状态变成"Starting"(启动中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在启动过程中, 当UDDB实例启动成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果启动过程中出现异常, 状态变成"Abnormal"(异常运行中), 或者"Shutoff"(已关闭)
    """

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class StartUDDBInstanceResponseSchema(schema.ResponseSchema):
    """StartUDDBInstance - 启动UDDB实例，开始提供服务。

    如下状态的UDDB实例可以进行这个操作:

    Shutoff: 已关闭
    当请求返回成功之后，UDDB实例的状态变成"Starting"(启动中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在启动过程中, 当UDDB实例启动成功之后, UDDB实例的状态变成"Running"(正常运行中); 如果启动过程中出现异常, 状态变成"Abnormal"(异常运行中), 或者"Shutoff"(已关闭)
    """

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: StopUDDBInstance

关闭UDDB实例，停止提供服务。

如下状态的UDDB实例可以进行这个操作:

Running: 正常运行中
Abnormal: 异常运行中
当请求返回成功之后，UDDB实例的状态变成"Shutdown"(关闭中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在关闭过程中, 当UDDB实例关闭成功之后, UDDB实例的状态变成"Shutoff"(已关闭); 如果关闭过程中出现异常, 根据UDDB实例的情况, 状态变成"Abnormal"(异常运行中), 或者"Running"(正常运行中)
"""


class StopUDDBInstanceRequestSchema(schema.RequestSchema):
    """StopUDDBInstance - 关闭UDDB实例，停止提供服务。

    如下状态的UDDB实例可以进行这个操作:

    Running: 正常运行中
    Abnormal: 异常运行中
    当请求返回成功之后，UDDB实例的状态变成"Shutdown"(关闭中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在关闭过程中, 当UDDB实例关闭成功之后, UDDB实例的状态变成"Shutoff"(已关闭); 如果关闭过程中出现异常, 根据UDDB实例的情况, 状态变成"Abnormal"(异常运行中), 或者"Running"(正常运行中)
    """

    fields = {
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class StopUDDBInstanceResponseSchema(schema.ResponseSchema):
    """StopUDDBInstance - 关闭UDDB实例，停止提供服务。

    如下状态的UDDB实例可以进行这个操作:

    Running: 正常运行中
    Abnormal: 异常运行中
    当请求返回成功之后，UDDB实例的状态变成"Shutdown"(关闭中); 如果返回失败, UDDB实例状态保持不变 UDDB实例在关闭过程中, 当UDDB实例关闭成功之后, UDDB实例的状态变成"Shutoff"(已关闭); 如果关闭过程中出现异常, 根据UDDB实例的情况, 状态变成"Abnormal"(异常运行中), 或者"Running"(正常运行中)
    """

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: UpgradeUDDBDataNode

升降级分布式数据库数据节点的配置, 提高/降低数据节点的数据容量和内存

所有数据节点以及其所挂载的只读实例的配置都受到影响

升降级数据节点的配置之后之后, 会按照数据节点新的磁盘和内存大小重新计费

如下状态的数据节点实例可以进行这个操作:

Shutoff: 已关闭
当请求返回成功之后，UDDB实例的状态变成"UpgradingDataNode"，相关数据节点的状态变成"Upgrading"; 如果返回失败, UDDB实例状态保持不变 当UDDB实例升级结束之后, UDDB实例的状态变成"Shutoff"
"""


class UpgradeUDDBDataNodeRequestSchema(schema.RequestSchema):
    """UpgradeUDDBDataNode - 升降级分布式数据库数据节点的配置, 提高/降低数据节点的数据容量和内存

    所有数据节点以及其所挂载的只读实例的配置都受到影响

    升降级数据节点的配置之后之后, 会按照数据节点新的磁盘和内存大小重新计费

    如下状态的数据节点实例可以进行这个操作:

    Shutoff: 已关闭
    当请求返回成功之后，UDDB实例的状态变成"UpgradingDataNode"，相关数据节点的状态变成"Upgrading"; 如果返回失败, UDDB实例状态保持不变 当UDDB实例升级结束之后, UDDB实例的状态变成"Shutoff"
    """

    fields = {
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "DataNodeDiskSpace": fields.Int(
            required=True, dump_to="DataNodeDiskSpace"
        ),
        "DataNodeMemory": fields.Int(required=True, dump_to="DataNodeMemory"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class UpgradeUDDBDataNodeResponseSchema(schema.ResponseSchema):
    """UpgradeUDDBDataNode - 升降级分布式数据库数据节点的配置, 提高/降低数据节点的数据容量和内存

    所有数据节点以及其所挂载的只读实例的配置都受到影响

    升降级数据节点的配置之后之后, 会按照数据节点新的磁盘和内存大小重新计费

    如下状态的数据节点实例可以进行这个操作:

    Shutoff: 已关闭
    当请求返回成功之后，UDDB实例的状态变成"UpgradingDataNode"，相关数据节点的状态变成"Upgrading"; 如果返回失败, UDDB实例状态保持不变 当UDDB实例升级结束之后, UDDB实例的状态变成"Shutoff"
    """

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: UpgradeUDDBInstance

升降级分布式数据库中间件的配置, 提高/降低请求处理的并发性

修改请求处理节点个数之后, 按照所有请求处理节点的总内存容量和CPU核数重新计费

如下状态的UDDB实例可以进行这个操作:

Running: 系统正常运行中
当请求返回成功之后，UDDB实例的状态变成"UpgradingUDDB"; 如果返回失败, UDDB实例状态保持不变 当UDDB实例升级成功之后, UDDB实例的状态变成"Running"; 如果更改过程中出现异常, 状态变成"Abnormal", 或者"Error"
"""


class UpgradeUDDBInstanceRequestSchema(schema.RequestSchema):
    """UpgradeUDDBInstance - 升降级分布式数据库中间件的配置, 提高/降低请求处理的并发性

    修改请求处理节点个数之后, 按照所有请求处理节点的总内存容量和CPU核数重新计费

    如下状态的UDDB实例可以进行这个操作:

    Running: 系统正常运行中
    当请求返回成功之后，UDDB实例的状态变成"UpgradingUDDB"; 如果返回失败, UDDB实例状态保持不变 当UDDB实例升级成功之后, UDDB实例的状态变成"Running"; 如果更改过程中出现异常, 状态变成"Abnormal", 或者"Error"
    """

    fields = {
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RouterNodeNum": fields.Int(required=True, dump_to="RouterNodeNum"),
        "RouterVersion": fields.Str(required=True, dump_to="RouterVersion"),
        "UDDBId": fields.Str(required=True, dump_to="UDDBId"),
        "Zone": fields.Str(required=False, dump_to="Zone"),
    }


class UpgradeUDDBInstanceResponseSchema(schema.ResponseSchema):
    """UpgradeUDDBInstance - 升降级分布式数据库中间件的配置, 提高/降低请求处理的并发性

    修改请求处理节点个数之后, 按照所有请求处理节点的总内存容量和CPU核数重新计费

    如下状态的UDDB实例可以进行这个操作:

    Running: 系统正常运行中
    当请求返回成功之后，UDDB实例的状态变成"UpgradingUDDB"; 如果返回失败, UDDB实例状态保持不变 当UDDB实例升级成功之后, UDDB实例的状态变成"Running"; 如果更改过程中出现异常, 状态变成"Abnormal", 或者"Error"
    """

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """

from ucloud.core.typesystem import schema, fields


class InterRegionBandwidthSchema(schema.ResponseSchema):
    """InterRegionBandwidth - 跨域带宽"""

    fields = {
        "Bandwidth": fields.Int(required=True, load_from="Bandwidth"),
        "ChargeType": fields.Str(required=True, load_from="ChargeType"),
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "ExpireTime": fields.Int(required=True, load_from="ExpireTime"),
        "InterRegionBandwidthId": fields.Str(
            required=True, load_from="InterRegionBandwidthId"
        ),
        "PayMode": fields.Str(required=True, load_from="PayMode"),
        "Region0": fields.Str(required=True, load_from="Region0"),
        "Region1": fields.Str(required=True, load_from="Region1"),
        "State": fields.Int(required=True, load_from="State"),
        "UGNId": fields.Str(required=True, load_from="UGNId"),
    }


class UGNSchema(schema.ResponseSchema):
    """UGN - 云联网信息"""

    fields = {
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "Instances": fields.List(fields.Str()),
        "InterRegionBandwidths": fields.List(fields.Str()),
        "Name": fields.Str(required=True, load_from="Name"),
        "Remark": fields.Str(required=True, load_from="Remark"),
        "RouteRules": fields.List(fields.Str()),
        "Tag": fields.Str(required=True, load_from="Tag"),
        "UGNId": fields.Str(required=True, load_from="UGNId"),
    }


class InstanceSchema(schema.ResponseSchema):
    """Instance - 云联网实例信息"""

    fields = {
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "InstanceId": fields.Str(required=True, load_from="InstanceId"),
        "InstanceOrganizationName": fields.Str(
            required=True, load_from="InstanceOrganizationName"
        ),
        "InstanceProjectId": fields.Str(
            required=True, load_from="InstanceProjectId"
        ),
        "InstanceRegion": fields.Str(required=True, load_from="InstanceRegion"),
        "InstanceType": fields.Str(required=True, load_from="InstanceType"),
        "Networks": fields.List(fields.Str()),
        "State": fields.Int(required=True, load_from="State"),
        "UGNId": fields.Str(required=True, load_from="UGNId"),
    }


class RouteRuleSchema(schema.ResponseSchema):
    """RouteRule - 云联网路由规则"""

    fields = {
        "CreateTime": fields.Int(required=True, load_from="CreateTime"),
        "DeriveInstanceId": fields.Str(
            required=True, load_from="DeriveInstanceId"
        ),
        "DeriveInstanceRegion": fields.Str(
            required=True, load_from="DeriveInstanceRegion"
        ),
        "DeriveInstanceType": fields.Str(
            required=True, load_from="DeriveInstanceType"
        ),
        "DeriveRouteRuleId": fields.Str(
            required=True, load_from="DeriveRouteRuleId"
        ),
        "DeriveRouteTableId": fields.Str(
            required=True, load_from="DeriveRouteTableId"
        ),
        "DstAddr": fields.Str(required=True, load_from="DstAddr"),
        "Enable": fields.Bool(required=True, load_from="Enable"),
        "NextHopId": fields.Str(required=True, load_from="NextHopId"),
        "NextHopType": fields.Str(required=True, load_from="NextHopType"),
        "Priority": fields.Int(required=True, load_from="Priority"),
        "Rollback": fields.Bool(required=True, load_from="Rollback"),
        "RouteRuleId": fields.Str(required=True, load_from="RouteRuleId"),
        "RouteRuleType": fields.Int(required=True, load_from="RouteRuleType"),
    }



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.utsdb.schemas import models

""" UTSDB API Schema
"""


"""
API: CheckUInfluxdbAllowance

检查UInfluxdb剩余资源
"""


class CheckUInfluxdbAllowanceRequestSchema(schema.RequestSchema):
    """CheckUInfluxdbAllowance - 检查UInfluxdb剩余资源"""

    fields = {
        "Count": fields.Int(required=True, dump_to="Count"),
        "CpuLimit": fields.Int(required=True, dump_to="CpuLimit"),
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CheckUInfluxdbAllowanceResponseSchema(schema.ResponseSchema):
    """CheckUInfluxdbAllowance - 检查UInfluxdb剩余资源"""

    fields = {
        "Count": fields.Int(required=True, load_from="Count"),
    }


"""
API: CreateUInfluxdbDatabase

创建Influxdb数据库
"""


class CreateUInfluxdbDatabaseRequestSchema(schema.RequestSchema):
    """CreateUInfluxdbDatabase - 创建Influxdb数据库"""

    fields = {
        "AccoutName": fields.Str(required=False, dump_to="AccoutName"),
        "DatabaseName": fields.Str(required=True, dump_to="DatabaseName"),
        "Description": fields.Str(required=False, dump_to="Description"),
        "ProjectId": fields.Str(required=True, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RetentionPolicy": fields.Str(
            required=False, dump_to="RetentionPolicy"
        ),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUInfluxdbDatabaseResponseSchema(schema.ResponseSchema):
    """CreateUInfluxdbDatabase - 创建Influxdb数据库"""

    fields = {}


"""
API: CreateUInfluxdbDatabaseRP

给指定的database创建一个保留策略，最多可以创建10个RP
"""


class CreateUInfluxdbDatabaseRPRequestSchema(schema.RequestSchema):
    """CreateUInfluxdbDatabaseRP - 给指定的database创建一个保留策略，最多可以创建10个RP"""

    fields = {
        "DatabaseName": fields.Str(required=True, dump_to="DatabaseName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RetentionPolicy": fields.Str(required=True, dump_to="RetentionPolicy"),
        "RetentionPolicyName": fields.Str(
            required=True, dump_to="RetentionPolicyName"
        ),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUInfluxdbDatabaseRPResponseSchema(schema.ResponseSchema):
    """CreateUInfluxdbDatabaseRP - 给指定的database创建一个保留策略，最多可以创建10个RP"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: CreateUInfluxdbInstance

创建UInfluxdb实例
"""


class CreateUInfluxdbInstanceRequestSchema(schema.RequestSchema):
    """CreateUInfluxdbInstance - 创建UInfluxdb实例"""

    fields = {
        "AccountName": fields.Str(required=True, dump_to="AccountName"),
        "ChargeType": fields.Str(required=True, dump_to="ChargeType"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "CpuLimit": fields.Int(required=True, dump_to="CpuLimit"),
        "DatabaseName": fields.Str(required=True, dump_to="DatabaseName"),
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "Name": fields.Str(required=True, dump_to="Name"),
        "Password": fields.Str(required=True, dump_to="Password"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=True, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "SubnetId": fields.Str(required=True, dump_to="SubnetId"),
        "Tag": fields.Str(required=False, dump_to="Tag"),
        "VPCId": fields.Str(required=True, dump_to="VPCId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class CreateUInfluxdbInstanceResponseSchema(schema.ResponseSchema):
    """CreateUInfluxdbInstance - 创建UInfluxdb实例"""

    fields = {
        "UInfluxdbId": fields.Str(required=True, load_from="UInfluxdbId"),
    }


"""
API: DeleteUInfluxdbDatabase

删除Influxdb实例的数据库
"""


class DeleteUInfluxdbDatabaseRequestSchema(schema.RequestSchema):
    """DeleteUInfluxdbDatabase - 删除Influxdb实例的数据库"""

    fields = {
        "DatabaseName": fields.Str(required=True, dump_to="DatabaseName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteUInfluxdbDatabaseResponseSchema(schema.ResponseSchema):
    """DeleteUInfluxdbDatabase - 删除Influxdb实例的数据库"""

    fields = {}


"""
API: DeleteUInfluxdbDatabaseRP

删除指定数据库下面的一个数据保留策略
"""


class DeleteUInfluxdbDatabaseRPRequestSchema(schema.RequestSchema):
    """DeleteUInfluxdbDatabaseRP - 删除指定数据库下面的一个数据保留策略"""

    fields = {
        "DatabaseName": fields.Str(required=True, dump_to="DatabaseName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RetentionPolicyName": fields.Str(
            required=True, dump_to="RetentionPolicyName"
        ),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteUInfluxdbDatabaseRPResponseSchema(schema.ResponseSchema):
    """DeleteUInfluxdbDatabaseRP - 删除指定数据库下面的一个数据保留策略"""

    fields = {
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: DeleteUInfluxdbInstance

删除UInfluxdb实例
"""


class DeleteUInfluxdbInstanceRequestSchema(schema.RequestSchema):
    """DeleteUInfluxdbInstance - 删除UInfluxdb实例"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DeleteUInfluxdbInstanceResponseSchema(schema.ResponseSchema):
    """DeleteUInfluxdbInstance - 删除UInfluxdb实例"""

    fields = {}


"""
API: DescribeUInfluxdbDatabase

描述UInfluxdb数据库
"""


class DescribeUInfluxdbDatabaseRequestSchema(schema.RequestSchema):
    """DescribeUInfluxdbDatabase - 描述UInfluxdb数据库"""

    fields = {
        "DatabaseName": fields.Str(required=False, dump_to="DatabaseName"),
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUInfluxdbDatabaseResponseSchema(schema.ResponseSchema):
    """DescribeUInfluxdbDatabase - 描述UInfluxdb数据库"""

    fields = {
        "DatabaseInfo": fields.List(
            models.DatabaseInfoSchema(), required=True, load_from="DatabaseInfo"
        ),
    }


"""
API: DescribeUInfluxdbDatabaseRP

获取指定数据库下面的所有保留策略
"""


class DescribeUInfluxdbDatabaseRPRequestSchema(schema.RequestSchema):
    """DescribeUInfluxdbDatabaseRP - 获取指定数据库下面的所有保留策略"""

    fields = {
        "DatabaseName": fields.Str(required=True, dump_to="DatabaseName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUInfluxdbDatabaseRPResponseSchema(schema.ResponseSchema):
    """DescribeUInfluxdbDatabaseRP - 获取指定数据库下面的所有保留策略"""

    fields = {
        "DataSet": fields.List(
            models.RpDataSchema(), required=True, load_from="DataSet"
        ),
        "Message": fields.Str(required=True, load_from="Message"),
    }


"""
API: DescribeUInfluxdbInstance

拉取UInfluxdb实例列表
"""


class DescribeUInfluxdbInstanceRequestSchema(schema.RequestSchema):
    """DescribeUInfluxdbInstance - 拉取UInfluxdb实例列表"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=False, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUInfluxdbInstanceResponseSchema(schema.ResponseSchema):
    """DescribeUInfluxdbInstance - 拉取UInfluxdb实例列表"""

    fields = {
        "DataSet": fields.List(
            models.UInfluxdbDataSetSchema(), required=True, load_from="DataSet"
        ),
    }


"""
API: DescribeUInfluxdbPrice

获取UInfluxdb价格
"""


class DescribeUInfluxdbPriceRequestSchema(schema.RequestSchema):
    """DescribeUInfluxdbPrice - 获取UInfluxdb价格"""

    fields = {
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CpuLimit": fields.Int(required=True, dump_to="CpuLimit"),
        "MemoryLimit": fields.Int(required=False, dump_to="MemoryLimit"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUInfluxdbPriceResponseSchema(schema.ResponseSchema):
    """DescribeUInfluxdbPrice - 获取UInfluxdb价格"""

    fields = {
        "OriginalPrice": fields.Float(
            required=False, load_from="OriginalPrice"
        ),
        "Price": fields.Float(required=True, load_from="Price"),
    }


"""
API: DescribeUInfluxdbUpgradePrice

获取UIfluxdb升降级价格
"""


class DescribeUInfluxdbUpgradePriceRequestSchema(schema.RequestSchema):
    """DescribeUInfluxdbUpgradePrice - 获取UIfluxdb升降级价格"""

    fields = {
        "CpuLimit": fields.Int(required=True, dump_to="CpuLimit"),
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class DescribeUInfluxdbUpgradePriceResponseSchema(schema.ResponseSchema):
    """DescribeUInfluxdbUpgradePrice - 获取UIfluxdb升降级价格"""

    fields = {
        "OriginalPrice": fields.Float(
            required=False, load_from="OriginalPrice"
        ),
        "TotalPrice": fields.Float(required=True, load_from="TotalPrice"),
    }


"""
API: ModifyUInfluxdbDatabasePolicy

更改UInfluxdb实例数据库数据保留策略
"""


class ModifyUInfluxdbDatabasePolicyRequestSchema(schema.RequestSchema):
    """ModifyUInfluxdbDatabasePolicy - 更改UInfluxdb实例数据库数据保留策略"""

    fields = {
        "DatabaseName": fields.Str(required=True, dump_to="DatabaseName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "RetentionPolicy": fields.Str(required=True, dump_to="RetentionPolicy"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class ModifyUInfluxdbDatabasePolicyResponseSchema(schema.ResponseSchema):
    """ModifyUInfluxdbDatabasePolicy - 更改UInfluxdb实例数据库数据保留策略"""

    fields = {}


"""
API: RebootUInfluxdbInstance

重启UInfluxdb实例
"""


class RebootUInfluxdbInstanceRequestSchema(schema.RequestSchema):
    """RebootUInfluxdbInstance - 重启UInfluxdb实例"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class RebootUInfluxdbInstanceResponseSchema(schema.ResponseSchema):
    """RebootUInfluxdbInstance - 重启UInfluxdb实例"""

    fields = {}


"""
API: ResetUInfluxdbInstanceName

更改UIfluxdb实例名称
"""


class ResetUInfluxdbInstanceNameRequestSchema(schema.RequestSchema):
    """ResetUInfluxdbInstanceName - 更改UIfluxdb实例名称"""

    fields = {
        "NewName": fields.Str(required=True, dump_to="NewName"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class ResetUInfluxdbInstanceNameResponseSchema(schema.ResponseSchema):
    """ResetUInfluxdbInstanceName - 更改UIfluxdb实例名称"""

    fields = {}


"""
API: StartUInfluxdbInstance

启动UInfluxdb实例
"""


class StartUInfluxdbInstanceRequestSchema(schema.RequestSchema):
    """StartUInfluxdbInstance - 启动UInfluxdb实例"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class StartUInfluxdbInstanceResponseSchema(schema.ResponseSchema):
    """StartUInfluxdbInstance - 启动UInfluxdb实例"""

    fields = {}


"""
API: StopUInfluxdbInstance

关闭UInfluxdb实例
"""


class StopUInfluxdbInstanceRequestSchema(schema.RequestSchema):
    """StopUInfluxdbInstance - 关闭UInfluxdb实例"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class StopUInfluxdbInstanceResponseSchema(schema.ResponseSchema):
    """StopUInfluxdbInstance - 关闭UInfluxdb实例"""

    fields = {}


"""
API: UpgradeUInfluxdbInstance

UInfluxdb实例配置升降级
"""


class UpgradeUInfluxdbInstanceRequestSchema(schema.RequestSchema):
    """UpgradeUInfluxdbInstance - UInfluxdb实例配置升降级"""

    fields = {
        "CpuLimit": fields.Int(required=True, dump_to="CpuLimit"),
        "MemoryLimit": fields.Int(required=True, dump_to="MemoryLimit"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=True, dump_to="Region"),
        "UInfluxdbId": fields.Str(required=True, dump_to="UInfluxdbId"),
        "Zone": fields.Str(required=True, dump_to="Zone"),
    }


class UpgradeUInfluxdbInstanceResponseSchema(schema.ResponseSchema):
    """UpgradeUInfluxdbInstance - UInfluxdb实例配置升降级"""

    fields = {}



""" Code is generated by ucloud-model, DO NOT EDIT IT. """


from ucloud.core.typesystem import schema, fields
from ucloud.services.udpn.schemas import models

""" UDPN API Schema
"""


"""
API: AllocateUDPN

分配一条 UDPN 专线
"""


class AllocateUDPNRequestSchema(schema.RequestSchema):
    """AllocateUDPN - 分配一条 UDPN 专线"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "PayMode": fields.Str(required=False, dump_to="PayMode"),
        "Peer1": fields.Str(required=True, dump_to="Peer1"),
        "Peer2": fields.Str(required=True, dump_to="Peer2"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=False, dump_to="Region"),
    }


class AllocateUDPNResponseSchema(schema.ResponseSchema):
    """AllocateUDPN - 分配一条 UDPN 专线"""

    fields = {
        "Action": fields.Str(required=True, load_from="Action"),
        "RetCode": fields.Int(required=True, load_from="RetCode"),
        "UDPNId": fields.Str(required=True, load_from="UDPNId"),
    }


"""
API: DescribeUDPN

描述 UDPN
"""


class DescribeUDPNRequestSchema(schema.RequestSchema):
    """DescribeUDPN - 描述 UDPN"""

    fields = {
        "Limit": fields.Int(required=False, dump_to="Limit"),
        "Offset": fields.Int(required=False, dump_to="Offset"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "UDPNId": fields.Str(required=False, dump_to="UDPNId"),
    }


class DescribeUDPNResponseSchema(schema.ResponseSchema):
    """DescribeUDPN - 描述 UDPN"""

    fields = {
        "DataSet": fields.List(
            models.UDPNDataSchema(), required=False, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: GetUDPNLineList

获取当前支持的专线线路列表
"""


class GetUDPNLineListRequestSchema(schema.RequestSchema):
    """GetUDPNLineList - 获取当前支持的专线线路列表"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
    }


class GetUDPNLineListResponseSchema(schema.ResponseSchema):
    """GetUDPNLineList - 获取当前支持的专线线路列表"""

    fields = {
        "DataSet": fields.List(
            models.UDPNLineSetSchema(), required=True, load_from="DataSet"
        ),
        "TotalCount": fields.Int(required=True, load_from="TotalCount"),
    }


"""
API: GetUDPNPrice

获取 UDPN 价格
"""


class GetUDPNPriceRequestSchema(schema.RequestSchema):
    """GetUDPNPrice - 获取 UDPN 价格"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "ChargeType": fields.Str(required=False, dump_to="ChargeType"),
        "PayMode": fields.Str(required=False, dump_to="PayMode"),
        "Peer1": fields.Str(required=True, dump_to="Peer1"),
        "Peer2": fields.Str(required=True, dump_to="Peer2"),
        "Quantity": fields.Int(required=False, dump_to="Quantity"),
        "Region": fields.Str(required=False, dump_to="Region"),
    }


class GetUDPNPriceResponseSchema(schema.ResponseSchema):
    """GetUDPNPrice - 获取 UDPN 价格"""

    fields = {
        "Price": fields.Float(required=True, load_from="Price"),
        "PurchaseValue": fields.Int(required=True, load_from="PurchaseValue"),
    }


"""
API: GetUDPNUpgradePrice

获取专线升级价格
"""


class GetUDPNUpgradePriceRequestSchema(schema.RequestSchema):
    """GetUDPNUpgradePrice - 获取专线升级价格"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "UDPNId": fields.Str(required=True, dump_to="UDPNId"),
    }


class GetUDPNUpgradePriceResponseSchema(schema.ResponseSchema):
    """GetUDPNUpgradePrice - 获取专线升级价格"""

    fields = {
        "Price": fields.Float(required=True, load_from="Price"),
    }


"""
API: ModifyUDPNBandwidth

修改带宽值
"""


class ModifyUDPNBandwidthRequestSchema(schema.RequestSchema):
    """ModifyUDPNBandwidth - 修改带宽值"""

    fields = {
        "Bandwidth": fields.Int(required=True, dump_to="Bandwidth"),
        "CouponId": fields.Str(required=False, dump_to="CouponId"),
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(
            required=False, dump_to="Region"
        ),  # Deprecated, will be removed at 1.0
        "UDPNId": fields.Str(required=True, dump_to="UDPNId"),
    }


class ModifyUDPNBandwidthResponseSchema(schema.ResponseSchema):
    """ModifyUDPNBandwidth - 修改带宽值"""

    fields = {}


"""
API: ReleaseUDPN

释放 UDPN
"""


class ReleaseUDPNRequestSchema(schema.RequestSchema):
    """ReleaseUDPN - 释放 UDPN"""

    fields = {
        "ProjectId": fields.Str(required=False, dump_to="ProjectId"),
        "Region": fields.Str(required=False, dump_to="Region"),
        "UDPNId": fields.Str(required=True, dump_to="UDPNId"),
    }


class ReleaseUDPNResponseSchema(schema.ResponseSchema):
    """ReleaseUDPN - 释放 UDPN"""

    fields = {}
